@@ -33,25 +33,18 @@ OC.L10N.register(
     "Start call" : "Starta samtal",
     "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
     "Go to file" : "Gå till fil",
+    "Guests" : "Gäster",
     "Share link" : "Dela länk",
     "Copy link" : "Kopiera länk",
-    "Enable for" : "Aktivera för",
-    "All participants" : "Alla deltagare",
-    "Moderators only" : "Endast moderatorer",
     "Start time (optional)" : "Starttid (valfritt)",
     "Change password" : "Byt lösenord",
     "Set password" : "Sätt lösenord",
-    "Error occurred while renaming the room" : "Fel uppstod vid namnändring av rum",
     "Name" : "Namn",
     "Conversation name" : "Konversationens namn",
     "Rename" : "Byt namn",
     "Link copied!" : "Länk kopierad!",
     "Conversation with {name}" : "Konversation med {name}",
-    "Error occurred while making the room public" : "Fel uppstod när rummet skulle göras offentligt",
-    "Error occurred while making the room private" : "Fel uppstod när rummet skulle göras privat",
     "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
-    "Error occurred while enabling for all participants" : "Fel uppstod vid aktivering för alla deltagare",
-    "Error occurred while enabling only for moderators" : "Fel uppstod vid aktivering för endast moderatorer",
     "Invalid start time format" : "Ogiltigt format för starttid",
     "Error occurred while setting the lobby start time" : "Fel uppstod vid inställning av starttid för lobby",
     "You" : "Du",
@@ -292,6 +285,7 @@ OC.L10N.register(
     "General settings" : "Allmänna inställningar",
     "Start calls" : "Starta samtal",
     "Users and moderators" : "Användare och moderatorer",
+    "Moderators only" : "Endast moderatorer",
     "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
     "Select conversation" : "Välj konversation",
     "Signaling servers" : "Signalservrar",
@@ -348,11 +342,18 @@ OC.L10N.register(
     "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
     "This call is password-protected" : "Detta samtal är lösenordsskyddat",
     "Signaling server" : "Signalserver",
+    "Error occurred while renaming the room" : "Fel uppstod vid namnändring av rum",
+    "Error occurred while making the room public" : "Fel uppstod när rummet skulle göras offentligt",
+    "Error occurred while making the room private" : "Fel uppstod när rummet skulle göras privat",
     "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
     "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "* En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
     "* You can now notify all participants by posting \"@all\" into the chat" : "* Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
     "* With the \"arrow-up\" key you can repost your last message" : "* Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
     "* Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "* Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
-    "* With projects you can create quick links between conversations, files and other items" : "* Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt"
+    "* With projects you can create quick links between conversations, files and other items" : "* Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
+    "Enable for" : "Aktivera för",
+    "All participants" : "Alla deltagare",
+    "Error occurred while enabling for all participants" : "Fel uppstod vid aktivering för alla deltagare",
+    "Error occurred while enabling only for moderators" : "Fel uppstod vid aktivering för endast moderatorer"
 },
 "nplurals=2; plural=(n != 1);");
